import json

from PyQt5.QtCore import Qt, QSize, QPoint, pyqtSignal
from PyQt5.QtGui import QPainter, QColor
from PyQt5.QtWidgets import QWidget
from documents.FileDefinition import LAYOUT_FILE
from src.model.Key import Key
from PySide6.QtCore import Signal

DEFAULT_COLOR = QColor("white")
OVER_COLOR = QColor("gray")

class KeyboardWidget(QWidget):
    newletter = pyqtSignal(str)
    def __init__(self):
        super().__init__()
        self.keys = []
        self.keyWidth = None
        self.keyHeight = None
        self.keySpacing = None

        self.keyboardWidth = 0
        self.keyboardHeight = 0

        self.mousePos = QPoint(0,0)
        self.pressedKey = None

        # Initialiser le clavier
        self.loadLayoutJson()
        self.setMouseTracking(True)
        self.update()

    def loadLayoutJson(self):
        # Chargement du fichier JSON contenant les paramètres du clavier
        with open(LAYOUT_FILE, "r") as f:
            layout_clavier = json.load(f)

        # Accéder aux paramètres

        self.keyWidth = layout_clavier['keyWidth']
        self.keyHeight = layout_clavier['keyHeight']
        self.keySpacing = layout_clavier['keySpacing']

        # Créer la clé de chaque touche
        for keyData in layout_clavier['keys']:
            self.keys.append(self.createKey(keyData))

    def createKey(self, keyData):
        key = Key(keyData['x'], keyData['y'], self.keyWidth, self.keyHeight, self.keySpacing, keyData['width'], keyData['symbol'])
        bottomRightPoint = key.rect.bottomRight()
        currentHeight = bottomRightPoint.y() + self.keySpacing
        currentWidth = bottomRightPoint.x() + self.keySpacing

        if self.keyboardHeight < currentHeight:
            self.keyboardHeight = currentHeight

        if self.keyboardHeight < currentWidth:
            self.keyboardWidth = currentWidth
        return key

    def paintEvent(self, event):
        self.sizeHint()
        for key in self.keys:
            if key.isOver(self.mousePos):
                self.paintKey(key, OVER_COLOR)
            else:
                self.paintKey(key, DEFAULT_COLOR)

    def sizeHint(self):
        return QSize(self.keyboardWidth, self.keyboardHeight)

    def mouseMoveEvent(self, event):
        self.mousePos = event.pos()
        self.update()

    def mousePressEvent(self, event):
        for key in self.keys:
            if key.isOver(self.mousePos):
                self.pressedKey = key
                return
    def mouseReleaseEvent(self, event):
        for key in self.keys:
            if key.isOver(self.mousePos):
                if key == self.pressedKey:
                    self.pressedKey = None
                    self.newletter.emit(key.symbol)
                    return
                else:
                    return

    def paintKey(self, key, color):
        painter = QPainter(self)
        painter.setBrush(color)
        painter.drawRect(key.rect)
        painter.drawText(key.rect, Qt.AlignCenter, key.symbol)
